Index: comm.c
===================================================================
--- comm.c	(revision 16091)
+++ comm.c	(working copy)
@@ -8,6 +8,7 @@
  *                  modified from WINE [ Onno Hovers, (onno@stack.urc.tue.nl) ]
  *					Robert Dickenson (robd@mok.lvcom.com)
  *					Saveliy Tretiakov (saveliyt@mail.ru)
+ *					Dmitry Philippov (shedon@mail.ru)
  * UPDATE HISTORY:
  *                  Created 01/11/98
  *                  RDD (30/09/2002) implemented many function bodies to call serial driver.
@@ -15,6 +16,8 @@
  *                  ST  (21/03/2005) implemented GetCommProperties
  *                  ST  (24/03/2005) implemented ClearCommError. Corrected many functions.
  *                  ST  (05/04/2005) implemented CommConfigDialog
+ *                  DP	(11/06/2005) implemented GetCommConfig
+ *                  DP	(12/06/2005) implemented SetCommConfig
  *
  */
 
@@ -927,14 +930,36 @@
 
 
 /*
- * @unimplemented
+ * @implemented
  */
 BOOL
 STDCALL
 GetCommConfig(HANDLE hCommDev, LPCOMMCONFIG lpCC, LPDWORD lpdwSize)
 {
-	SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
-	return FALSE;
+	BOOL ReturnValue = FALSE;
+
+	DPRINT("GetCommConfig(%d, %p, %p)\n", hCommDev, lpCC, lpdwSize);
+
+	if( (NULL == lpdwSize) 
+		|| (NULL == lpCC) ) {
+			DPRINT("GetCommConfig() - invalid parameter\n");
+			SetLastError(STATUS_INVALID_PARAMETER);
+			ReturnValue = FALSE;
+	}
+	else
+	{
+		*lpdwSize = sizeof(COMMCONFIG);
+		lpCC->dwSize = *lpdwSize;
+		lpCC->wVersion = 1;
+		lpCC->wReserved = 0;
+		lpCC->dwProviderSubType = PST_RS232;
+		lpCC->dwProviderOffset = 0;
+		lpCC->dwProviderSize = 0;
+		lpCC->wcProviderData[0] = 0;
+		ReturnValue = GetCommState(hCommDev, &lpCC->dcb);
+	}
+
+	return (ReturnValue);
 }
 
 
@@ -1160,14 +1185,28 @@
 
 
 /*
- * @unimplemented
+ * @implemented
  */
 BOOL
 STDCALL
 SetCommConfig(HANDLE hCommDev, LPCOMMCONFIG lpCC, DWORD dwSize)
 {
-	SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
-	return FALSE;
+	BOOL ReturnValue = FALSE;
+
+	DPRINT("SetCommConfig(%d, %p, %d)\n", hCommDev, lpCC, dwSize);
+
+	if(NULL == lpCC)
+	{
+		DPRINT("SetCommConfig() - invalid parameter\n");
+		SetLastError(STATUS_INVALID_PARAMETER);
+		ReturnValue = FALSE;
+	}
+	else
+	{
+		ReturnValue = SetCommState(hCommDev, &lpCC->dcb);
+	}
+
+	return ReturnValue;
 }
 
 
